@@ -9,17 +9,18 @@ from django.http.response import HttpResponse
 
 
 class Analytics:
-    def __init__(self, get_response: Callable[[WSGIRequest], HttpResponse]) -> None:
+    def __init__(self, get_response: Callable[[WSGIRequest], HttpResponse]):
         self.get_response = get_response
         self.api_key = getattr(conf.settings, "ANALYTICS_API_KEY", None)
 
     def __call__(self, request: WSGIRequest) -> HttpResponse:
         start = time()
         response = self.get_response(request)
-
+        
         data = {
             'api_key': self.api_key,
             'hostname': request.get_host(),
+            'ip_address': request.META.get('REMOTE_ADDR'),
             'path': request.path,
             'user_agent': request.headers['user-agent'],
             'method': request.method,
