@@ -2,23 +2,24 @@ import threading
 from time import time
 
 from api_analytics.core import log_request
-
-from tornado.web import RequestHandler
+from tornado.web import Application, RequestHandler
+from tornado.httputil import HTTPServerRequest
 
 
 class Analytics(RequestHandler):
-    def __init__(self, app, res, api_key):
+    def __init__(self, app: Application, res: HTTPServerRequest, api_key: str):
         super().__init__(app, res)
         self.api_key = api_key
-        self.start = None
+        self.start = time()
 
-    async def prepare(self):
+    def prepare(self):
         self.start = time()
 
     def on_finish(self):
         data = {
             'api_key': self.api_key,
             'hostname': self.request.host,
+            'ip_address': self.request.remote_ip,
             'path': self.request.path,
             'user_agent': self.request.headers['user-agent'],
             'method': self.request.method,
